==> zio-aws-macie2_2.12-5.19.7.1-sources.jar: zio/aws/macie2/model/BucketSortCriteria.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.macie2.model.primitives.__string
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class BucketSortCriteria(
    attributeName: Optional[__string] = Optional.Absent,
    orderBy: Optional[zio.aws.macie2.model.OrderBy] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.BucketSortCriteria = {
    import BucketSortCriteria.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.BucketSortCriteria
      .builder()
      .optionallyWith(attributeName.map(value => value: java.lang.String))(
        _.attributeName
      )
      .optionallyWith(orderBy.map(value => value.unwrap))(_.orderBy)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.BucketSortCriteria.ReadOnly =
    zio.aws.macie2.model.BucketSortCriteria.wrap(buildAwsValue())
}
object BucketSortCriteria {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.BucketSortCriteria
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.BucketSortCriteria =
      zio.aws.macie2.model.BucketSortCriteria(
        attributeName.map(value => value),
        orderBy.map(value => value)
      )
    def attributeName: Optional[__string]
    def orderBy: Optional[zio.aws.macie2.model.OrderBy]
    def getAttributeName: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("attributeName", attributeName)
    def getOrderBy: ZIO[Any, AwsError, zio.aws.macie2.model.OrderBy] =
      AwsError.unwrapOptionField("orderBy", orderBy)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.BucketSortCriteria
  ) extends zio.aws.macie2.model.BucketSortCriteria.ReadOnly {
    override val attributeName: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.attributeName())
      .map(value => value: __string)
    override val orderBy: Optional[zio.aws.macie2.model.OrderBy] =
      zio.aws.core.internal
        .optionalFromNullable(impl.orderBy())
        .map(value => zio.aws.macie2.model.OrderBy.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.BucketSortCriteria
  ): zio.aws.macie2.model.BucketSortCriteria.ReadOnly = new Wrapper(impl)
}

==> zio-aws-macie2_2.13-5.17.104.12-sources.jar: zio/aws/macie2/model/BucketSortCriteria.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class BucketSortCriteria(
    attributeName: Option[__string] = None,
    orderBy: Option[zio.aws.macie2.model.OrderBy] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.BucketSortCriteria = {
    import BucketSortCriteria.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.BucketSortCriteria
      .builder()
      .optionallyWith(
        attributeName.map(value => __string.unwrap(value): java.lang.String)
      )(_.attributeName)
      .optionallyWith(orderBy.map(value => value.unwrap))(_.orderBy)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.BucketSortCriteria.ReadOnly =
    zio.aws.macie2.model.BucketSortCriteria.wrap(buildAwsValue())
}
object BucketSortCriteria {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.BucketSortCriteria
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.BucketSortCriteria =
      zio.aws.macie2.model.BucketSortCriteria(
        attributeName.map(value => value),
        orderBy.map(value => value)
      )
    def attributeName: Option[__string]
    def orderBy: Option[zio.aws.macie2.model.OrderBy]
    def getAttributeName: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("attributeName", attributeName)
    def getOrderBy: ZIO[Any, AwsError, zio.aws.macie2.model.OrderBy] =
      AwsError.unwrapOptionField("orderBy", orderBy)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.BucketSortCriteria
  ) extends zio.aws.macie2.model.BucketSortCriteria.ReadOnly {
    override val attributeName: Option[__string] = scala
      .Option(impl.attributeName())
      .map(value => zio.aws.macie2.model.primitives.__string(value))
    override val orderBy: Option[zio.aws.macie2.model.OrderBy] = scala
      .Option(impl.orderBy())
      .map(value => zio.aws.macie2.model.OrderBy.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.BucketSortCriteria
  ): zio.aws.macie2.model.BucketSortCriteria.ReadOnly = new Wrapper(impl)
}
